@@ -21,6 +21,7 @@
 #include <wibble/test.h>
 #include <wibble/exception.h>
 #include <errno.h>
+#include <unistd.h>
 
 using namespace std;
 namespace wex = wibble::exception;
@@ -43,6 +44,7 @@ struct TestException {
 
     Test system() 
     {
+#ifdef POSIX
         try {
             assert_eq(access("does-not-exist", F_OK), -1);
             throw wex::System("checking for existance of nonexisting file");
@@ -59,6 +61,7 @@ struct TestException {
             assert_eq(e.code(), ENOENT);
             assert(e.fullInfo().find("does-not-exist") != string::npos);
         }
+#endif
     }
 
     Test badCast()
