@@ -25,9 +25,13 @@ FileSender::~FileSender()
 
 void FileSender::send(Level level, const std::string& msg)
 {
+#ifndef __gnu_hurd__
+#ifdef POSIX // FIXME
 	// Write it all in a single write(2) so multiple processes can log to
 	// the same file
 	sys::fs::FileLock lock(out, F_WRLCK);
+#endif
+#endif
 
     // Seek to end of file
     if (lseek(out, 0, SEEK_END) < 0)
