@@ -1,5 +1,6 @@
 #include <wibble/log/syslog.h>
 
+#ifdef POSIX
 namespace wibble {
 namespace log {
 
@@ -31,5 +32,5 @@ void SyslogSender::send(Level level, const std::string& msg)
 
 }
 }
-
+#endif
 // vim:set ts=4 sw=4:
