@@ -163,10 +163,10 @@ bool Request::read_buf(std::string& res, size_t size)
     size_t pos = 0;
     while (true)
     {
-        ssize_t r = read(sock, (void*)((char*)res.data() + pos), size - pos);
+        ssize_t r = read( sock, const_cast< char* >( res.data() ) + pos, size - pos );
         if (r < 0)
             throw wibble::exception::System("reading data from socket");
-        if ((size_t)r == size - pos)
+        if (static_cast<size_t>(r) == size - pos)
             break;
         else if (r == 0)
         {
@@ -225,6 +225,7 @@ void Request::set_cgi_env()
 {
     // Set CGI server-specific variables
 
+#ifdef POSIX // FIXME
     // SERVER_SOFTWARE — name/version of HTTP server.
     setenv("SERVER_SOFTWARE", server_software.c_str(), 1);
     // SERVER_NAME — host name of the server, may be dot-decimal IP address.
@@ -288,6 +289,7 @@ void Request::set_cgi_env()
                 name.append(1, '_');
         setenv(name.c_str(), i->second.c_str(), 1);
     }
+#endif
 }
 
 void Request::send(const std::string& buf)
@@ -321,7 +323,11 @@ void Request::send_date_header()
 {
     time_t now = time(NULL);
     struct tm t;
+#ifdef POSIX
     gmtime_r(&now, &t);
+#else
+    t = *gmtime(&now);
+#endif
     char tbuf[256];
     size_t size = strftime(tbuf, 256, "%a, %d %b %Y %H:%M:%S GMT", &t);
     if (size == 0)
