@@ -5,7 +5,10 @@
 
 namespace wibble {
 
-struct Unit {};
+struct Unit {
+    bool operator<( Unit ) const { return false; }
+    bool operator==( Unit ) const { return true; }
+};
 
 struct TTrue {
     static const bool value = true;
@@ -77,9 +80,18 @@ struct EnableIfC {};
 template< typename Type >
 struct EnableIfC< true, Type > { typedef Type T; };
 
+template< bool, typename T = Unit >
+struct DisableIfC {};
+
+template< typename Type >
+struct DisableIfC< false, Type > { typedef Type T; };
+
 template< typename X, typename T = Unit >
 struct EnableIf : EnableIfC< X::value, T > {};
 
+template< typename X, typename T = Unit >
+struct DisableIf : DisableIfC< X::value, T > {};
+
 template< typename A, typename B >
 struct TPair {
     typedef A First;
