@@ -30,6 +30,7 @@
 #include <string>
 #include <set>
 #include <vector>
+#include <deque>
 #include <sstream>
 #include <cctype>
 #ifdef _WIN32
@@ -46,7 +47,6 @@ using namespace wibble::operators;
 static int vasprintf (char **, const char *, va_list);
 #endif
 
-std::string fmt( const char* f, ... ) __attribute__ ((deprecated));
 std::string fmtf( const char* f, ... );
 template< typename T > inline std::string fmt(const T& val);
 
@@ -114,6 +114,12 @@ inline std::string fmt(const std::vector< X > &val) {
     return fmt_container( val, '[', ']' );
 }
 
+// formatting vectors using [ ... ] notation
+template< typename X >
+inline std::string fmt(const std::deque< X > &val) {
+    return fmt_container( val, '[', ']' );
+}
+
 /// Given a pathname, return the file name without its path
 inline std::string basename(const std::string& pathname)
 {
@@ -267,6 +273,20 @@ inline std::string joinpath(const std::string& path1, const std::string& path2)
 			return path1 + '/' + path2;
 }
 
+// append path2 to path1 if path2 is not absolute, otherwise return path2
+inline std::string appendpath( const std::string &path1, const std::string &path2 ) {
+#ifdef POSIX
+    if ( path2.size() >= 1 && path2[ 0 ] == '/' )
+        return path2;
+#endif
+#ifdef WIN32
+    if ( ( path2.size() >= 3 && path2[ 1 ] == ':' && path2[ 2 ] == '\\' )
+            || ( path2.size() >= 2 && path2[ 0 ] == '\\' && path2[ 1 ] == '\\' ) )
+        return path2;
+#endif
+    return joinpath( path1, path2 );
+}
+
 /// Urlencode a string
 std::string urlencode(const std::string& str);
 
@@ -450,6 +470,21 @@ public:
 	const_iterator end() { return const_iterator(); }
 };
 
+/**
+ * Escape the string so it can safely used as a C string inside double quotes
+ */
+std::string c_escape(const std::string& str);
+
+/**
+ * Unescape a C string, stopping at the first double quotes or at the end of
+ * the string.
+ *
+ * lenParsed is set to the number of characters that were pased (which can be
+ * greather than the size of the resulting string in case escapes were found)
+ */
+std::string c_unescape(const std::string& str, size_t& lenParsed);
+
+
 }
 }
 
