@@ -2,17 +2,23 @@
    (c) 2007 Enrico Zini <enrico@enricozini.org> */
 #include <wibble/sys/childprocess.h>
 
-#ifdef POSIX
 #include <wibble/sys/process.h>
 #include <wibble/sys/exec.h>
 #include <cstdlib>
+#include <unistd.h>
 #include <iostream>
+#include <unistd.h>
 
 #include <wibble/test.h>
 
+
 using namespace std;
 using namespace wibble::sys;
 
+#ifdef _WIN32
+#define sleep Sleep
+#endif
+
 class EndlessChild : public ChildProcess
 {
 protected:
@@ -54,6 +60,7 @@ struct TestChildprocess {
 
     // Try running the child process and kill it
     Test kill() {
+#ifdef POSIX
         EndlessChild child;
 
         // Start the child
@@ -69,12 +76,17 @@ struct TestChildprocess {
         int res = child.wait();
 
         // Check that it was indeed terminated by signal 2
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wold-style-cast"
         assert(WIFSIGNALED(res));
         assert_eq(WTERMSIG(res), 2);
+#pragma GCC diagnostic pop
+#endif
     }
 
     // Try getting the output of the child process
     Test output() {
+#ifdef POSIX
         TestChild child;
         int out;
 
@@ -87,10 +99,12 @@ struct TestChildprocess {
 
         // Wait for the child to terminate
         assert_eq(child.wait(), 0);
+#endif
     }
 
     Test redirect() {
-        Exec child("/bin/echo");
+        Exec child("echo");
+        child.searchInPath = true;
         child.args.push_back("antani");
         int out;
 	
@@ -120,6 +134,23 @@ struct TestChildprocess {
         assert_eq(child.wait(), 0);
     }
 
+    Test inout() {
+        Exec child("cat");
+        child.searchInPath = true;
+        int in, out;
+	
+        // Fork the child redirecting its stdout
+        child.forkAndRedirect(&in, &out, 0);
+        // assert(pid != 0);
+        write(in, "hello\n", 6);
+        close(in);
+
+        // Read the child output
+        assert_eq(suckFd(out), "hello\n");
+
+        // Wait for the child to terminate
+        assert_eq(child.wait(), 0);
+    }
+
 };
-#endif
 // vim:set ts=4 sw=4:
