@@ -46,33 +46,48 @@ void Exec::importEnv()
 		env.push_back(*s);
 }
 
+void Exec::spawnChild()
+{
+#ifdef _WIN32
+    std::string cmd = pathname;
+    for ( int i = 1; i < args.size(); ++i )
+        cmd += " \"" + args[i] + "\""; // FIXME: quoting...
+    std::cerr << "CreateProcess: " << cmd << std::endl;
+    CreateProcess( NULL, (char*)cmd.c_str(), NULL, NULL, TRUE, 0, NULL, NULL, &si, &pi );
+#endif
+}
+
 void Exec::exec()
 {
-	// Prepare the argument list
-        char** exec_args = (char **) alloca(args.size() + 1);
-	for (size_t i = 0; i < args.size(); ++i)
-		exec_args[i] = strdup(args[i].c_str());
-	exec_args[args.size()] = 0;
+    // Prepare the argument list
+    char** exec_args = new char*[args.size() + 1];
+    for (size_t i = 0; i < args.size(); ++i)
+        exec_args[i] = strdup(args[i].c_str());
+    exec_args[args.size()] = 0;
 
-	if (searchInPath)
-	{
-		if (execvp(pathname.c_str(), exec_args) == -1)
-			throw wibble::exception::System("trying to run " + pathname);
-	} else if (envFromParent) {
-		if (execve(pathname.c_str(), exec_args, environ) == -1)
-			throw wibble::exception::System("trying to run " + pathname);
-	} else {
-		// Prepare the custom environment
-                char ** exec_env = (char **) alloca (env.size() + 1);
-		for (size_t i = 0; i < env.size(); ++i)
-			// We can just store a pointer to the internal strings, since later
-			// we're calling exec and no destructors will be called
-			exec_env[i] = strdup(env[i].c_str());
-		exec_env[env.size()] = 0;
+    char** exec_env = environ;
+    if (!envFromParent)
+    {
+        // Prepare the custom environment
+        exec_env = new char*[env.size() + 1];
+        for (size_t i = 0; i < env.size(); ++i)
+            // We can just store a pointer to the internal strings, since later
+            // we're calling exec and no destructors will be called
+            exec_env[i] = strdup(env[i].c_str());
+        exec_env[env.size()] = 0;
+    }
 
-		if (execve(pathname.c_str(), exec_args, exec_env) == -1)
-			throw wibble::exception::System("trying to run " + pathname);
-	}
+    if (searchInPath)
+    {
+        if (execvpe(pathname.c_str(), exec_args, exec_env) == -1)
+            throw wibble::exception::System("trying to run " + pathname);
+    } else {
+        if (execve(pathname.c_str(), exec_args, exec_env) == -1)
+            throw wibble::exception::System("trying to run " + pathname);
+    }
+
+    delete[] exec_args;
+    if (exec_env != environ) delete[] exec_env;
 	throw wibble::exception::Consistency(
 			"trying to run " + pathname,
 			"Program flow continued after successful exec()");
