@@ -1,5 +1,5 @@
-#ifndef EXEC_H
-#define EXEC_H
+#ifndef WIBBLE_SYS_EXEC_H
+#define WIBBLE_SYS_EXEC_H
 
 /*
  * OO wrapper for execve
@@ -38,6 +38,7 @@ protected:
 	 * ChildProcess::fork functions is called. Simply calls exec()
 	 */
 	virtual int main();
+	virtual void spawnChild();
 
 public:
 	virtual ~Exec() {}
@@ -96,7 +97,12 @@ public:
 class ShellCommand : public Exec
 {
 public:
-	ShellCommand(const std::string& cmd) : Exec("/bin/sh")
+	ShellCommand(const std::string& cmd) :
+#ifdef POSIX
+                Exec("/bin/sh")
+#elif defined _WIN32
+                Exec("bash") // let's hope for the best...
+#endif
 	{
 		args.push_back("-c");
 		args.push_back(cmd);
