@@ -28,13 +28,18 @@
 
 namespace wibble {
 namespace sys {
-
+#if __cplusplus >= 201103L
+inline namespace v1 {
+#endif
 /**
  * Map a file into memory.
  *
  * Currently, this is only read-only.
  *
  * Copy semanthics are the same as auto_ptr
+ *
+ * Note: on 32bit systems, it is not possible to map files larger than 2G into
+ * memory.
  */
 struct MMap
 {
@@ -56,6 +61,9 @@ public:
 
 };
 
+#if __cplusplus >= 201103L
+}
+#endif
 }
 }
 
