@@ -19,7 +19,6 @@
  */
 #include <wibble/sys/mmap.h>
 
-#ifdef POSIX
 #include <wibble/test.h>
 #include <string.h>
 
@@ -28,17 +27,18 @@ using namespace wibble::sys;
 
 struct TestMMap {
     Test simple() {
+#ifdef POSIX
         MMap map;
         assert_eq(map.filename, string());
         assert_eq(map.fd, -1);
         assert_eq(map.size, 0u);
-        assert_eq(map.buf, (const char*)0);
+        assert_eq(map.buf, static_cast<const char*>(0));
 
-    	map.map("/bin/ls");
-        assert_eq(map.filename, "/bin/ls");
+    	map.map("/bin/sh");
+        assert_eq(map.filename, "/bin/sh");
         assert(map.fd != -1);
         assert(map.size != 0u);
-        assert(map.buf != (const char*)0);
+        assert(map.buf != static_cast<const char*>(0));
     	assert_eq(map.buf[1], 'E');
     	assert_eq(map.buf[2], 'L');
     	assert_eq(map.buf[3], 'F');
@@ -47,12 +47,12 @@ struct TestMMap {
         assert_eq(map.filename, string());
         assert_eq(map.fd, -1);
         assert_eq(map.size, 0u);
-        assert_eq(map.buf, (const char*)0);
+        assert_eq(map.buf, static_cast<const char*>(0));
 
-        assert_eq(map1.filename, "/bin/ls");
+        assert_eq(map1.filename, "/bin/sh");
         assert(map1.fd != -1);
         assert(map1.size != 0u);
-        assert(map1.buf != (const char*)0);
+        assert(map1.buf != static_cast<const char*>(0));
     	assert_eq(map1.buf[1], 'E');
     	assert_eq(map1.buf[2], 'L');
     	assert_eq(map1.buf[3], 'F');
@@ -61,8 +61,8 @@ struct TestMMap {
         assert_eq(map1.filename, string());
         assert_eq(map1.fd, -1);
         assert_eq(map1.size, 0u);
-        assert_eq(map1.buf, (const char*)0);
+        assert_eq(map1.buf, static_cast<const char*>(0));
+#endif
     }
 };
-#endif
 // vim:set ts=4 sw=4:
