@@ -24,17 +24,18 @@
 namespace wibble {
 namespace sys {
 
+#ifdef POSIX
 bool Condition::wait(MutexLock& l, const struct timespec& abstime)
 {
-#ifdef POSIX
-	if (int res = pthread_cond_timedwait(&cond, &l.mutex.mutex, &abstime))
+	if (int res = pthread_cond_timedwait(&cond, &l.mutex.mutex, &abstime)) {
 		if (res == ETIMEDOUT)
 			return false;
 		else
 			throw wibble::exception::System(res, "waiting on a pthread condition");
+	}
 	return true;
-#endif
 }
+#endif
 
 }
 }
