@@ -31,12 +31,8 @@
 #include <windows.h>
 #include <queue>
 #include <time.h>
-struct timespec 
-{
-  time_t   tv_sec;        /* seconds */
-  long     tv_nsec;       /* nanoseconds */
-};
 #endif
+
 #include <errno.h>
 
 namespace wibble {
@@ -72,6 +68,10 @@ public:
                 pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_RECURSIVE );
 #else
                 pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_RECURSIVE_NP );
+#endif
+            } else {
+#ifndef NDEBUG
+                pthread_mutexattr_settype( &attr, PTHREAD_MUTEX_ERRORCHECK_NP );
 #endif
             }
     res = pthread_mutex_init(&mutex, &attr);
@@ -88,7 +88,7 @@ public:
 			throw wibble::exception::System(res, "creating pthread mutex");
 	}
 
-  Mutex( const Mutex & m )
+  Mutex( const Mutex & )
 	{
     int res = 0;
 #ifdef POSIX
@@ -299,7 +299,7 @@ public:
 			throw wibble::exception::System(res, "creating pthread condition");
 	}
 
-  Condition( const Condition & con )
+  Condition( const Condition & )
 	{
 		int res = 0;
 #ifdef POSIX
@@ -498,6 +498,7 @@ public:
 			throw wibble::exception::System(res, "waiting on a pthread condition");
 	}
 
+#ifdef POSIX
 	/**
 	 * Wait on the condition, locking with l.  l is unlocked before waiting and
 	 * locked again before returning.  If the time abstime is reached before
@@ -509,6 +510,7 @@ public:
 	 *   the condition is signaled.
 	 */
 	bool wait(MutexLock& l, const struct timespec& abstime);
+#endif
 };
 
 }
