@@ -5,6 +5,8 @@
 #ifdef POSIX
 #include <fcntl.h>
 #include <sys/select.h>
+#endif
+#include <unistd.h>
 
 #include <deque>
 #include <cerrno>
@@ -12,6 +14,7 @@
 #include <wibble/exception.h>
 #include <wibble/sys/thread.h>
 #include <wibble/sys/mutex.h>
+#include <wibble/sys/exec.h>
 
 #ifndef WIBBLE_SYS_PIPE_H
 #define WIBBLE_SYS_PIPE_H
@@ -45,13 +48,19 @@ struct Pipe {
                 }
 
                 if ( wrote == -1 ) {
-                    if ( errno == EAGAIN || errno == EWOULDBLOCK )
+                    if ( blocking( errno ) )
+#ifdef POSIX
                         sched_yield();
+#else
+                        ;
+#endif
                     else
                         throw wexcept::System( "writing to pipe" );
                 }
             } while ( !done() );
 
+            wibble::sys::MutexLock __l( mutex );
+            running = false;
             if ( close )
                 ::close( fd );
 
@@ -91,8 +100,10 @@ struct Pipe {
     {
         if ( p == -1 )
             return;
+#ifdef POSIX
         if ( fcntl( fd, F_SETFL, O_NONBLOCK ) == -1 )
             throw wexcept::System( "fcntl on a pipe" );
+#endif
     }
     Pipe() : fd( -1 ), _eof( false ) {}
 
@@ -102,8 +113,10 @@ struct Pipe {
     }
 
     void close() {
+        wibble::sys::MutexLock __l( writer.mutex );
         writer.close = true;
-        writer.run( fd, "" );
+        if ( !writer.running )
+            ::close( fd );
     }
 
     bool valid() {
@@ -118,11 +131,19 @@ struct Pipe {
         return _eof;
     }
 
+    static bool blocking( int err ) {
+#ifdef POSIX
+        return err == EAGAIN || err == EWOULDBLOCK;
+#else
+	return err == EAGAIN;
+#endif
+    }
+
     int readMore() {
         assert( valid() );
         char _buffer[1024];
         int r = ::read( fd, _buffer, 1023 );
-        if ( r == -1 && errno != EAGAIN && errno != EWOULDBLOCK )
+        if ( r == -1 && !blocking( errno ) )
             throw wexcept::System( "reading from pipe" );
         else if ( r == -1 )
             return 0;
@@ -160,15 +181,24 @@ struct Pipe {
     /* Only returns on eof() or when data is buffered. */
     void wait() {
         assert( valid() );
+#ifdef POSIX
         fd_set fds;
         FD_ZERO( &fds );
+#endif
         while ( buffer.empty() && !eof() ) {
             if ( readMore() )
                 return;
             if ( eof() )
                 return;
+#ifdef POSIX
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wold-style-cast"           
             FD_SET( fd, &fds );
             select( fd + 1, &fds, 0, 0, 0 );
+#pragma GCC diagnostic pop
+#else
+            sleep( 1 );
+#endif
         }
     }
     std::string nextLineBlocking() {
@@ -187,7 +217,37 @@ struct Pipe {
 
 };
 
+struct PipeThrough
+{
+    std::string cmd;
+
+    PipeThrough( const std::string& _cmd ) : cmd( _cmd ) {}
+
+    std::string run( std::string data ) {
+        int _in, _out;
+
+#ifdef _WIN32
+        Exec exec(cmd);
+#elif defined POSIX
+        ShellCommand exec(cmd);
+#endif
+
+        exec.setupRedirects( &_in, &_out, 0 );
+        exec.fork();
+
+        Pipe in( _in ), out( _out );
+
+        in.write( data );
+        in.close();
+        std::string ret;
+        while ( !out.eof() ) {
+            out.wait();
+            ret += out.nextChunk();
+        }
+        return ret;
+    }
+};
+
 }
 }
 #endif
-#endif
