@@ -60,11 +60,14 @@ string formatStatus(int status)
 {
 	stringstream b_status;
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wold-style-cast"
 	bool exited_normally = WIFEXITED(status);
 	int exit_code = exited_normally ? WEXITSTATUS(status) : -1;
 	bool dumped_core = status & 128;
 	bool signaled = WIFSIGNALED(status);
 	int signal = signaled ? WTERMSIG(status) : 0;
+#pragma GCC diagnostic pop
 
 	if (exited_normally)
 		if (exit_code == 0)
@@ -400,5 +403,27 @@ void setproctitle(const std::string& title) {}
 }
 }
 }
+#elif defined(_WIN32)
+
+#include <stdlib.h>
+#include <stdio.h>
+#include <unistd.h>
+
+namespace wibble {
+namespace sys {
+namespace process {
+
+std::string getcwd()
+{
+	char *buf = (char *)alloca( 4096 );
+	if (::getcwd(buf, 4096) == NULL)
+		throw wibble::exception::System("getting the current working directory");
+	return buf;
+}
+
+}
+}
+}
+
 #endif
 // vim:set ts=4 sw=4:
