@@ -10,16 +10,20 @@ using namespace wibble::sys;
 
 struct TestProcess {
     Test getcwdAndChdir() {
+#ifdef POSIX
         string cwd = process::getcwd();
         process::chdir("/");
         assert_eq(process::getcwd(), string("/"));
         process::chdir(cwd);
         assert_eq(process::getcwd(), cwd);
+#endif
     }
 
     Test umask() {
+#ifdef POSIX
         mode_t old = process::umask(0012);
         assert_eq(process::umask(old), 0012u);
+#endif
     }
 
 };
