@@ -7,21 +7,26 @@
 #ifndef WIBBLE_TEST_H
 #define WIBBLE_TEST_H
 
+namespace wibble {
+
 // TODO use TLS
 extern int assertFailure;
 
 struct Location {
     const char *file;
     int line, iteration;
-    const char *stmt;
-    Location( const char *f, int l, const char *st, int iter = -1 )
+    std::string stmt;
+    Location( const char *f, int l, std::string st, int iter = -1 )
         : file( f ), line( l ), iteration( iter ), stmt( st ) {}
 };
 
-#define LOCATION(stmt) Location( __FILE__, __LINE__, stmt )
+#define LOCATION(stmt) ::wibble::Location( __FILE__, __LINE__, stmt )
+
+#undef assert // silence a gcc warning if we had assert.h included
 
 #ifndef NDEBUG
-#define LOCATION_I(stmt, i) Location( __FILE__, __LINE__, stmt, i )
+#define LOCATION_I(stmt, i) ::wibble::Location( __FILE__, __LINE__, stmt, i )
+
 #define assert(x) assert_fn( LOCATION( #x ), x )
 #define assert_pred(p, x) assert_pred_fn( \
         LOCATION( #p "( " #x " )" ), x, p( x ) )
@@ -42,6 +47,8 @@ struct Location {
 #define assert_list_eq(x, y) ((void)0)
 #endif
 
+#define assert_unreachable(...) assert_die_fn( LOCATION( wibble::str::fmtf(__VA_ARGS__) ) )
+#define assert_unimplemented() assert_die_fn( LOCATION( "not imlemented" ) )
 #define assert_die() assert_die_fn( LOCATION( "forbidden code path tripped" ) )
 
 struct AssertFailed {
@@ -154,8 +161,10 @@ inline void beginAssertFailure() {
 }
 
 inline void endAssertFailure() {
-    int f = assertFailure;
+#ifndef NDEBUG
+    const int f = assertFailure;
     assertFailure = 0;
+#endif
     assert( f > 1 );
 }
 
@@ -164,6 +173,8 @@ struct ExpectFailure {
     ~ExpectFailure() { endAssertFailure(); }
 };
 
+}
+
 typedef void Test;
 
 #endif
